AskQuestionEntry class

Constructors

AskQuestionEntry({required String question, required List<AskQuestionOption> options, bool isMultiSelect = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
isMultiSelect bool
final
options List<AskQuestionOption>
final
question String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited