GeminiModelOptions class

Gemini-specific model options.

Mixed-in types
Annotations
  • @MappableClass.new(caseStyle: CaseStyle.snakeCase, ignoreNull: true)

Constructors

GeminiModelOptions({ThinkingLevel? thinkingLevel})

Properties

copyWith GeminiModelOptionsCopyWith<GeminiModelOptions, GeminiModelOptions, GeminiModelOptions>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thinkingLevel ThinkingLevel?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
inherited
toMap() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited