TemplatedSystemInstructionsCopyWith<$R, $In extends TemplatedSystemInstructions, $Out> class abstract

Implemented types
Available extensions

Properties

$asTemplatedSystemInstructions TemplatedSystemInstructionsCopyWith<$R, TemplatedSystemInstructions, $Out>

Available on ObjectCopyWith<$R, TemplatedSystemInstructions, $Out>, provided by the TemplatedSystemInstructionsValueCopy extension

no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sections → ListCopyWith<$R, SystemInstructionSection, SystemInstructionSectionCopyWith<$R, SystemInstructionSection, SystemInstructionSection>>
no setter

Methods

$chain<$R2, $Out2>(Then<$Out2, $R2> t) TemplatedSystemInstructionsCopyWith<$R2, $In, $Out2>
override
$delta(Map<String, dynamic> delta) → $R
inherited
$merge($In value) → $R
inherited
$update($Out transform($In)) → $R
inherited
call({String? identity, List<SystemInstructionSection>? sections}) → $R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited