Video class

Inheritance

Constructors

Video({required String mimeType, required String description, required List<int> data})
Video.fromFile(String path, {String description = ''})
factory

Properties

data List<int>
finalinherited
description String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
mimeType String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited