HarnessDownloader class
A utility to dynamically download the official precompiled localharness
binary from PyPI wheels matching the host CPU architecture and OS.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
downloadAndInstall(
) → Future< String> -
Downloads the correct
localharnessbinary for the host system and installs it. -
getProcessorArchitecture(
) → Future< String> - Detects the current CPU architecture.
-
getWheelPlatformTag(
) → Future< String?> - Resolves the PyPI wheel platform name matching the host environment.
Constants
- defaultVersion → const String
- Fallback version of google-antigravity to query if PyPI's latest resolution fails.