McpStdioServer class
- Inheritance
-
- Object
- McpServerConfig
- McpStdioServer
- Mixed-in types
- Annotations
-
- @MappableClass.new(caseStyle: CaseStyle.snakeCase, discriminatorValue: 'stdio', ignoreNull: true)
Constructors
Properties
-
args
→ List<
String> -
final
- command → String
-
final
-
copyWith
→ McpStdioServerCopyWith<
McpStdioServer, McpStdioServer, McpStdioServer> -
no setterinherited
-
disabledTools
→ List<
String> ? -
finalinherited
-
enabledTools
→ List<
String> ? -
finalinherited
-
env
→ Map<
String, String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeoutSeconds → int?
-
finalinherited
- type → String
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
inherited
-
toMap(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fromJson → const McpStdioServer Function(String json)
-
fromMap
→ const McpStdioServer Function(Map<
String, dynamic> map)