OnCompactionHook class abstract
Invoked when a conversation context compaction event occurs.
- Inheritance
-
- Object
- InspectHook
- OnCompactionHook
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
HookContext context, dynamic data) → Future< void> -
Executes the inspection hook logic with the given
contextanddata.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited