OnToolErrorHook class abstract
Invoked when a tool fails, allowing recovery or transformation of the exception.
- Inheritance
-
- Object
- TransformHook<
Exception, dynamic> - OnToolErrorHook
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
HookContext context, Exception data) → Future -
Executes the transformation hook logic, transforming
datainto typeRwith the givencontext.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited